@@ -1,5 +1,5 @@
 `Emax` <-
-function(x, old, K, method, Sdist,p)
+function(x, old, K, method, Sdist,p, cutpoint)
 #old...matrix with probabilites for group membership
 
 {
@@ -14,15 +14,17 @@ prior <- matrix(prior.vec,nrow=K,ncol=p,byrow=TRUE)            #matrix of prior
 old[old==0] <- min(old[old>0])      #0-weights in survreg not allowed (replaced with minimum)
 
 if (method=="separate") {
-   parlist <- apply(old,2,function(y) {                   #old is matrix with posteriors
-               apply(x,2,function(z) {
-                 wphm <- survreg(Surv(z[z>0])~1,weights=y[z>0],dist=Sdist)
+  parlist <- apply(old,2,function(y) {                   #old is matrix with posteriors
+                apply(x,2,function(z) {
+                 censvec <- rep(1, length(z))   
+                 censvec[z > cutpoint] <- 0     #vector for censored data (set to 0)          
+                 wphm <- survreg(Surv(z[z>0], censvec[z>0])~1, weights = y[z>0], dist = Sdist)
                  shapep <- 1/wphm$scale
                  scalep <- exp(wphm$coefficients[1])
                  list(scalep,shapep)
-                 }) })
+                 })})
   shsclist <- tapply(unlist(parlist),rep(1:2,length(unlist(parlist))/2),function(z){
-                             matrix(z,nrow=K,byrow=TRUE)})                         #reorganizing parlist
+                                          matrix(z,nrow=K,byrow=TRUE)})                         #reorganizing parlist
   shape <- shsclist[[2]]                                                      #shape matrix K,p
   scale <- shsclist[[1]]
   anzpar <- 2*K*p
