@@ -21,8 +21,8 @@ function(x,...)
   cat("Number of clusters:",x$K,"\n")
   cat("\n")
   cat("Cluster means: \n")
-  colnames(x$clmean) <- paste("V",1:dim(x$clmean)[2],sep="")
-  rownames(x$clmean) <- paste("Cluster",1:x$K,sep="")
+  #colnames(x$clmean) <- paste("V",1:dim(x$clmean)[2],sep="")
+  #rownames(x$clmean) <- paste("Cluster",1:x$K,sep="")
   print(x$clmean)
   cat("\n")
 }
